function figure_wire(surf, Ecolor, Fcolor);
%
%figure_wire(surf, Ecolor, Fcolor);
%
% The function colors mesh faces and edges 
%
% surf  : surface mesh
% Ecolor: edge color 
% Fcolor: face color
%
% For instance, we can have Ecolor=[0.8 0.8 0.8]
%
% (C) Moo K. Chung 
%  mkchung@wisc.edu
%  Department of Biostatisics and Medical Informatics
%  University of Wisconsin, Madison



%surf= reducepatch(surf,0.2); 

background='white';
whitebg(gcf,background);

p=patch(surf);
set(p,'FaceColor',Fcolor,'EdgeColor',Ecolor);

daspect([1 1 1]);
%view(view_angle);  
axis tight
camlight; 


set(gcf,'Color',background,'InvertHardcopy','off');

lighting gouraud
material shiny; 
%shading interp;

%alpha(0.5);